@@ -73,7 +73,7 @@ static char *mime_encode(const unsigned char *data) {
 	char *ret;
 	int i, x=0;
 
-	datalen = strlen(data);
+	datalen = strlen((char *) data);
 
 	/* Size of actual charectars to fill. */
 	outlen = (int) (((double) datalen) * 1.3333333 + 0.9);
@@ -312,7 +312,11 @@ double set_clock(const struct timeval *tvdata, int allow_adj, int ignoreusec) {
  */
 static time_t get_server_time(const char *host, unsigned int port, const char *proxyhost, unsigned int proxyport, const char *credentials) {
 	unsigned int         server_s;		/* Server socket descriptor */
-	struct sockaddr_in   server_addr;	/* Server Internet address */
+	struct addrinfo      *addrs = NULL, *curr; /* Name resolution structure */
+	struct sockaddr      *server_addr;	/* Server Internet address */
+	struct sockaddr_in   server_addr_v4;	/* Server Internet address (IPv4) */
+	struct sockaddr_in6  server_addr_v6;	/* Server Internet address (IPv6) */
+	socklen_t            server_addr_len;
 	char                 out_buf[2048];	/* Output buffer for HEAD request */
 	char                 in_buf[2048];	/* Input buffer for response */
 	int 		     retcode;		/* Return code */
@@ -321,8 +325,8 @@ static time_t get_server_time(const char *host, unsigned int port, const char *p
 	char			*pdate;
 	const char		*connect_host = NULL;
 	unsigned int		connect_port = 0;
-	struct			hostent	*hostinfo;
 	time_t			remote_timeval = -1, retval = -1;
+	int                     gai_ret;
 
 	if (proxyhost == NULL) {
 		connect_host = host;
@@ -332,22 +336,47 @@ static time_t get_server_time(const char *host, unsigned int port, const char *p
 		connect_port = proxyport;
 	}
 
-	hostinfo = gethostbyname(connect_host);
-	if (!hostinfo) {
+	gai_ret = getaddrinfo(connect_host, "http", NULL, &addrs);
+	if (gai_ret != 0 || addrs == NULL) {
 		return(-1);
 	}
 
-	/* Create a socket */
-	server_s = socket(AF_INET, SOCK_STREAM, 0);
+	for (curr = addrs; curr; curr = curr->ai_next) {
+		/* Create a socket */
+		server_s = socket(curr->ai_family, SOCK_STREAM, 0);
 
-	/* The web server socket's address information */
-	server_addr.sin_family = AF_INET;
-	server_addr.sin_port = htons(connect_port);
-	server_addr.sin_addr = *(struct in_addr *)*hostinfo -> h_addr_list;
+		/* The web server socket's address information */
+		switch (curr->ai_family) {
+			case AF_INET:
+				server_addr = (struct sockaddr *) &server_addr_v4;
+				memcpy(server_addr, curr->ai_addr, curr->ai_addrlen);
+				server_addr_v4.sin_port = htons(connect_port);
+				server_addr_len = sizeof(server_addr_v4);
+				break;
+			case AF_INET6:
+				server_addr = (struct sockaddr *) &server_addr_v6;
+				memcpy(server_addr, curr->ai_addr, curr->ai_addrlen);
+				server_addr_v6.sin6_port = htons(connect_port);
+				server_addr_len = sizeof(server_addr_v6);
+				break;
+		}
+
+		/* Do a connect (connect() blocks) */
+		retcode = connect(server_s, server_addr, server_addr_len);
+		if ( retcode < 0 ) {
+			close(server_s);
+
+			continue;
+		}
+
+		break;
+	}
+
+	freeaddrinfo(addrs);
+
+	if (retcode < 0) {
+		close(server_s);
 
-	/* Do a connect (connect() blocks) */
-	retcode = connect(server_s, (struct sockaddr *)&server_addr, sizeof(server_addr));
-	if ( retcode < 0 ) {
 		return(-1);
 	}
 
@@ -548,7 +577,7 @@ struct timeval *htp_calctime(struct timeserver_st *timeservers, unsigned int tot
 
 	if (username != NULL && password != NULL) {
 		snprintf(tmpbuf, sizeof(tmpbuf), "%s:%s", username, password);
-		authcredentials = mime_encode(tmpbuf);
+		authcredentials = mime_encode((unsigned char *) tmpbuf);
 	}
 
 	for (timeind = 0; timeind < totaltimeservers; timeind++) {	
