@@ -85,6 +85,7 @@ static char *http_proxy = NULL;
 static long maxsleeptime = 43200, minsleeptime = 4096;
 static char *proxy_username = NULL;
 static char *proxy_password = NULL;
+static int disallow_adj = 0;
 
 #ifdef _USE_WIN32_
 /*
@@ -132,7 +133,7 @@ int htpd_loop(void) {
 		newtime = htp_calctime(timeservers, totaltimeservers, http_proxy, http_proxy_port, proxy_username, proxy_password);
 
 		if (newtime != NULL) {
-			delta = set_clock(newtime, 1, 1);
+			delta = set_clock(newtime, !disallow_adj, 1);
 		} else {
 			delta = 0.0;
 		}
@@ -794,6 +795,8 @@ int main(int argc, char *argv[]) {
 	lc_register_var("MinSleep", LC_VAR_LONG, &minsleeptime, 'm');
 	lc_register_var("ProxyUser", LC_VAR_STRING, &proxy_username, 'U');
 	lc_register_var("ProxyPass", LC_VAR_STRING, &proxy_password, 'p');
+	lc_register_var("NoAdjustTime", LC_VAR_BOOL_BY_EXISTANCE, &disallow_adj, 'n');
+
 	lc_p_ret = lc_process(argc, argv, "htpd", LC_CONF_SPACE, SYSCONFDIR "/htpd.conf");
 	if (lc_p_ret < 0) {
 		fprintf(stderr, "Error processing configuration information: %s.\n", lc_geterrstr());
