@@ -35,10 +35,14 @@
 
 int print_help(const char *shortvar, const char *var, const char *arguments, const char *value, lc_flags_t flags, void *extra) {
 	printf("htpdate version " PACKAGE_VERSION "\n");
-	printf("Usage: htpdate [-anh] <host> [<host> [<host> [...]]]\n");
+	printf("Usage: htpdate [-anh] [-P proxy] [-U user] [-p pass]\n");
+	printf("               <host> [<host> [<host> [...]]]\n");
 	printf("   -a        Allow htpdate to slew the time instead of setting it.\n");
 	printf("   -n        Do not actually set the clock, just print the new time.\n");
 	printf("   -h        This help information.\n");
+	printf("   -P proxy  Proxy to connect through.\n");
+	printf("   -U user   Username for proxy authentication.\n");
+	printf("   -p pass   Password for proxy authentication.\n");
 	printf("   host      Host to query for time, in the format of hostname[:port]\n");
 	exit(EXIT_SUCCESS);
 }
@@ -51,6 +55,7 @@ int main(int argc, char *argv[]) {
 	double delta = 0.0;
 	char *host = NULL, *portstr = NULL;
 	char *proxyhost = NULL, *proxyportstr = NULL;
+	char *proxy_username = NULL, *proxy_password = NULL;
 	char strtime[128];
 	int port = -1, proxyport = -1;
 	int allowadj = 0;
@@ -65,12 +70,15 @@ int main(int argc, char *argv[]) {
 
 	lc_register_var("AdjustTime", LC_VAR_BOOL_BY_EXISTANCE, &allowadj, 'a');
 	lc_register_var("QueryOnly", LC_VAR_BOOL_BY_EXISTANCE, &queryonly, 'n');
-        lc_register_callback(NULL, 'h', LC_VAR_NONE, print_help, NULL);
-        lc_p_ret = lc_process(argc, argv, "htpdate", LC_CONF_SPACE, SYSCONFDIR "/htpdate.conf");
-        if (lc_p_ret < 0) {
-                fprintf(stderr, "Error processing configuration information: %s.\n", lc_geterrstr());
-                return(EXIT_FAILURE);
-        }
+	lc_register_var("ProxyUser", LC_VAR_STRING, &proxy_username, 'U');
+	lc_register_var("ProxyPass", LC_VAR_STRING, &proxy_password, 'p');
+	lc_register_var("ProxyHost", LC_VAR_STRING, &proxyhost, 'P');
+	lc_register_callback(NULL, 'h', LC_VAR_NONE, print_help, NULL);
+	lc_p_ret = lc_process(argc, argv, "htpdate", LC_CONF_SPACE, SYSCONFDIR "/htpdate.conf");
+	if (lc_p_ret < 0) {
+		fprintf(stderr, "Error processing configuration information: %s.\n", lc_geterrstr());
+		return(EXIT_FAILURE);
+	}
 
 	/* Process each argument as a host:port pair. */
 	for (argind = lc_optind; argind < (unsigned int) argc; argind++) {
@@ -108,9 +116,11 @@ int main(int argc, char *argv[]) {
 		return(EXIT_FAILURE);
 	}
 
-	proxyhost = getenv("http_proxy");
 	if (proxyhost == NULL) {
-		proxyhost = getenv("HTTP_PROXY");
+		proxyhost = getenv("http_proxy");
+		if (proxyhost == NULL) {
+			proxyhost = getenv("HTTP_PROXY");
+		}
 	}
 
 	if (proxyhost != NULL) {
@@ -123,10 +133,12 @@ int main(int argc, char *argv[]) {
 				printf("Illegal proxy port: %s.\n", proxyportstr);
 				return(EXIT_FAILURE);
 			}
+		} else {
+			proxyport = 8080;
 		}
 	}
 
-	newtime = htp_calctime(timeservers, totaltimeservers, proxyhost, proxyport);
+	newtime = htp_calctime(timeservers, totaltimeservers, proxyhost, proxyport, proxy_username, proxy_password);
 
 	if (newtime == NULL) {
 		fprintf(stderr, "No servers could be reached.\n");
@@ -134,7 +146,7 @@ int main(int argc, char *argv[]) {
 	}
 
 	if (!queryonly) {
-		delta = set_clock(newtime, allowadj);
+		delta = set_clock(newtime, allowadj, 1);
 	}
 
 	strftime(strtime, sizeof(strtime), "%a %b %d %H:%M:%S %Y", localtime(&newtime->tv_sec));
