@@ -22,17 +22,17 @@
 int settimeofday(const struct timeval *tv , void *tz) {
 	int retval = -1;
 #ifdef _USE_WIN32_
-	struct tm *lt = NULL;
+	struct tm *gmt = NULL;
 	SYSTEMTIME st;
 
-	lt = gmtime(&(tv->tv_sec));
+	gmt = gmtime(&(tv->tv_sec));
 
-	st.wYear = lt->tm_year + 1900;
-	st.wMonth = lt->tm_mon + 1;
-	st.wDay = lt->tm_mday;
-	st.wHour = lt->tm_hour;
-	st.wMinute = lt->tm_min;
-	st.wSecond = lt->tm_sec;
+	st.wYear = gmt->tm_year + 1900;
+	st.wMonth = gmt->tm_mon + 1;
+	st.wDay = gmt->tm_mday;
+	st.wHour = gmt->tm_hour;
+	st.wMinute = gmt->tm_min;
+	st.wSecond = gmt->tm_sec;
 	st.wMilliseconds = tv->tv_usec / 1000;
 
 	if (SetSystemTime(&st)) {
